@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 SerialConnection unittest class.
 
@@ -25,51 +24,42 @@ class TestSerialConnection:
         Invoked for every test function in the module.
         """
         conf = {
-            'serial_port': "/tmp/vmodem1",
+            'serial_port': SerialConnection.get_virtual_home_serial_port("vmodem1"),
             'baud': 19200,
             'timeout': 0,
         }
 
-        if not SerialConnection.is_serial_port_exists("/tmp/vmodem1"):
-            conf.update(
-                {'serial_port': SerialConnection.get_virtual_home_serial_port("vmodem1")}
-            )
         self.obj = SerialConnection(**conf)
 
-    def teardown_method(self):
-        """ teardown any state that was previously setup with a setup_function
-        call.
-        """
-        pass
-
     def test_settings(self):
-        """Test configuration settings from SerialConnection constructor"""
+        """Test configuration settings from SerialConnection constructor."""
         assert self.obj.is_settings()
 
     def test_set_timeout(self):
-        """Test set_timeout method"""
+        """Test set_timeout method."""
         assert self.obj.set_timeout(0)
         assert self.obj.set_timeout(10)
         assert not self.obj.set_timeout(-1)
         assert not self.obj.set_timeout("hello")
 
     def test_set_source_name(self):
-        """Test set_source_name method"""
+        """Test set_source_name method."""
         assert self.obj.set_source_name("hello")
         assert not self.obj.set_source_name("")
         assert not self.obj.set_source_name(-1)
         assert not self.obj.set_source_name(None)
 
-    def test_get_virtual_ports_paths(self):
-        """Test get_virtual_ports_paths method"""
+    @staticmethod
+    def test_get_virtual_ports_paths():
+        """Test get_virtual_ports_paths method."""
         paths = SerialConnection.get_virtual_ports_paths()
-        assert Ut.is_list(paths) and len(paths) == 2
-        assert paths[0] == "/tmp"
-        assert paths[1] == os.path.expanduser('~')
+        assert Ut.is_list(paths) and len(paths) == 1
+        assert paths[0] == os.path.expanduser('~')
 
     # noinspection PyTypeChecker
-    def test_get_virtual_home_serial_port(self):
-        """Test get_virtual_home_serial_port method"""
+    @staticmethod
+    def test_get_virtual_home_serial_port():
+        """Test get_virtual_home_serial_port method."""
         v_ports = [
             SerialConnection.get_virtual_home_serial_port("vmodem999"),
             SerialConnection.get_virtual_home_serial_port("vmodem0"),
@@ -83,9 +73,10 @@ class TestSerialConnection:
         assert len(tests) == 2
 
     # noinspection PyTypeChecker
-    def test_is_virtual_serial_port(self):
-        """Test is_virtual_serial_port method"""
-        v_ports = [
+    @staticmethod
+    def test_is_virtual_serial_port():
+        """Test is_virtual_serial_port method."""
+        virtual_ports = [
             SerialConnection.get_virtual_home_serial_port("vmodem999"),
             SerialConnection.get_virtual_home_serial_port("vmodem0"),
             SerialConnection.get_virtual_home_serial_port("vmodem"),
@@ -94,11 +85,12 @@ class TestSerialConnection:
             SerialConnection.get_virtual_home_serial_port(1),
             SerialConnection.get_virtual_home_serial_port(dict())
         ]
-        tests = [x for x in v_ports if SerialConnection.is_virtual_serial_port(x)]
+        tests = [x for x in virtual_ports if SerialConnection.is_virtual_serial_port(x)]
         assert len(tests) == 2
 
-    def test_split_serial_port(self):
-        """Test split_serial_port method"""
+    @staticmethod
+    def test_split_serial_port():
+        """Test split_serial_port method."""
         ports = [
             "r",
             "/r",
@@ -109,22 +101,20 @@ class TestSerialConnection:
         tests = [x for x in ports if SerialConnection.split_serial_port(x)[0] == 'r']
         assert len(tests) == 3
 
-    def test_is_serial_port_exists(self):
-        """Test is_serial_port_exists method"""
+    @staticmethod
+    def test_is_serial_port_exists():
+        """Test is_serial_port_exists method."""
         ports = [
-            "/tmp/vmodem0",
-            "/tmp/vmodem1",
             SerialConnection.get_virtual_home_serial_port("vmodem0"),
             SerialConnection.get_virtual_home_serial_port("vmodem1")
         ]
         tests = [x for x in ports if SerialConnection.is_serial_port_exists(x)]
         assert len(tests) == 2
 
-    def test_is_serial_port(self):
-        """Test is_serial_port method"""
+    @staticmethod
+    def test_is_serial_port():
+        """Test is_serial_port method."""
         ports = [
-            "/tmp/vmodem0",
-            "/tmp/vmodem1",
             SerialConnection.get_virtual_home_serial_port("vmodem0"),
             SerialConnection.get_virtual_home_serial_port("vmodem1"),
             "/dev/ttyUSB1",
@@ -139,12 +129,12 @@ class TestSerialConnection:
             "/dev/1",  # false
         ]
         tests = [x for x in ports if SerialConnection.is_serial_port(x)]
-        assert len(tests) == 10
+        assert len(tests) == 8
 
-    def test_is_serial_path(self):
-        """Test is_serial_path method"""
+    @staticmethod
+    def test_is_serial_path():
+        """Test is_serial_path method."""
         paths = [
-            "/tmp",  # true
             os.path.expanduser('~'),  # true
             "/dev",  # true
             "/dev/pts/",
@@ -157,10 +147,11 @@ class TestSerialConnection:
             None
         ]
         tests = [x for x in paths if SerialConnection.is_serial_path(x)]
-        assert len(tests) == 3
+        assert len(tests) == 2
 
-    def test_is_baud(self):
-        """Test is_baud method"""
+    @staticmethod
+    def test_is_baud():
+        """Test is_baud method."""
         bauds = [
             110, 300, 600, 1200,
             2400, 4800, 9600, 14400,
@@ -171,8 +162,9 @@ class TestSerialConnection:
         tests = [x for x in bauds if SerialConnection.is_baud(x)]
         assert len(tests) == 14
 
-    def test_is_timeout(self):
-        """Test is_timeout method"""
+    @staticmethod
+    def test_is_timeout():
+        """Test is_timeout method."""
         timeouts = [
             1, 5, 10, 0.1, 0, None,
             "2400"
@@ -181,9 +173,9 @@ class TestSerialConnection:
         assert len(tests) == 6
 
     def test_set_serial_conf(self):
-        """Test set_serial_conf method"""
+        """Test set_serial_conf method."""
         conf = {
-            'serial_port': "/tmp/vmodem0",
+            'serial_port': SerialConnection.get_virtual_home_serial_port("vmodem0"),
             'baud': 19200,
             'timeout': 0,
             'write_timeout': 0,
@@ -193,17 +185,17 @@ class TestSerialConnection:
         assert Ut.is_dict(result, eq=5)
 
     def test_connect(self):
-        """Test connect method"""
+        """Test connect method."""
         assert self.obj.connect()
         assert self.obj.is_serial_ready()
         assert self.obj.is_ready()
-        
+
     def test_get_serial_ports_list(self):
-        """Test get_serial_ports_list method"""
+        """Test get_serial_ports_list method."""
         serial_ports = self.obj.get_serial_ports_list()
         assert Ut.is_list(serial_ports) and len(serial_ports) == 2
 
     def test_get_unix_virtual_serial_ports_list(self):
-        """Test get_unix_virtual_serial_ports_list method"""
+        """Test get_unix_virtual_serial_ports_list method."""
         serial_ports = self.obj.get_unix_virtual_serial_ports_list()
         assert Ut.is_list(serial_ports) and len(serial_ports) == 2
